@@ -10,13 +10,15 @@
 
 void siridb_init_props(void);
 
+
 typedef void (* siridb_props_cb)(
         siridb_t * siridb,
         qp_packer_t * packer,
         int flags);
 
-siridb_props_cb siridb_props[KW_COUNT];
+siridb_props_cb props_get_cb(int i);
+void props_set_who_am_i(char * s);
+char * props_get_who_am_i(void);
 
-char * who_am_i;
 
 #endif  /* SIRIDB_PROPS_H_ */
