@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2020-01-23 14:08:47
+ * Created at: 2020-09-25 10:57:26
  */
 #ifndef CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
 #define CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
@@ -22,9 +22,11 @@ enum cleri_grammar_ids {
     CLERI_GID_AGGREGATE_FUNCTIONS,
     CLERI_GID_ALTER_DATABASE,
     CLERI_GID_ALTER_GROUP,
+    CLERI_GID_ALTER_SERIES,
     CLERI_GID_ALTER_SERVER,
     CLERI_GID_ALTER_SERVERS,
     CLERI_GID_ALTER_STMT,
+    CLERI_GID_ALTER_TAG,
     CLERI_GID_ALTER_USER,
     CLERI_GID_BEFORE_EXPR,
     CLERI_GID_BETWEEN_EXPR,
@@ -40,6 +42,7 @@ enum cleri_grammar_ids {
     CLERI_GID_COUNT_SHARDS,
     CLERI_GID_COUNT_SHARDS_SIZE,
     CLERI_GID_COUNT_STMT,
+    CLERI_GID_COUNT_TAGS,
     CLERI_GID_COUNT_USERS,
     CLERI_GID_CREATE_GROUP,
     CLERI_GID_CREATE_STMT,
@@ -50,6 +53,7 @@ enum cleri_grammar_ids {
     CLERI_GID_DROP_SERVER,
     CLERI_GID_DROP_SHARDS,
     CLERI_GID_DROP_STMT,
+    CLERI_GID_DROP_TAG,
     CLERI_GID_DROP_USER,
     CLERI_GID_F_ALL,
     CLERI_GID_F_COUNT,
@@ -57,6 +61,7 @@ enum cleri_grammar_ids {
     CLERI_GID_F_DIFFERENCE,
     CLERI_GID_F_FILTER,
     CLERI_GID_F_FIRST,
+    CLERI_GID_F_INTERVAL,
     CLERI_GID_F_LAST,
     CLERI_GID_F_LIMIT,
     CLERI_GID_F_MAX,
@@ -69,12 +74,13 @@ enum cleri_grammar_ids {
     CLERI_GID_F_PVARIANCE,
     CLERI_GID_F_STDDEV,
     CLERI_GID_F_SUM,
+    CLERI_GID_F_TIMEVAL,
     CLERI_GID_F_VARIANCE,
     CLERI_GID_GRANT_STMT,
     CLERI_GID_GRANT_USER,
     CLERI_GID_GROUP_COLUMNS,
-    CLERI_GID_GROUP_MATCH,
     CLERI_GID_GROUP_NAME,
+    CLERI_GID_GROUP_TAG_MATCH,
     CLERI_GID_HELP_ACCESS,
     CLERI_GID_HELP_ALTER,
     CLERI_GID_HELP_ALTER_DATABASE,
@@ -168,6 +174,7 @@ enum cleri_grammar_ids {
     CLERI_GID_K_INSERT,
     CLERI_GID_K_INTEGER,
     CLERI_GID_K_INTERSECTION,
+    CLERI_GID_K_INTERVAL,
     CLERI_GID_K_IP_SUPPORT,
     CLERI_GID_K_LAST,
     CLERI_GID_K_LENGTH,
@@ -214,6 +221,7 @@ enum cleri_grammar_ids {
     CLERI_GID_K_SERVERS,
     CLERI_GID_K_SET,
     CLERI_GID_K_SHARDS,
+    CLERI_GID_K_SHARD_DURATION,
     CLERI_GID_K_SHOW,
     CLERI_GID_K_SID,
     CLERI_GID_K_SIZE,
@@ -226,14 +234,18 @@ enum cleri_grammar_ids {
     CLERI_GID_K_SUM,
     CLERI_GID_K_SYMMETRIC_DIFFERENCE,
     CLERI_GID_K_SYNC_PROGRESS,
+    CLERI_GID_K_TAG,
+    CLERI_GID_K_TAGS,
     CLERI_GID_K_TEE_PIPE_NAME,
     CLERI_GID_K_TIMEIT,
+    CLERI_GID_K_TIMEVAL,
     CLERI_GID_K_TIMEZONE,
     CLERI_GID_K_TIME_PRECISION,
     CLERI_GID_K_TO,
     CLERI_GID_K_TRUE,
     CLERI_GID_K_TYPE,
     CLERI_GID_K_UNION,
+    CLERI_GID_K_UNTAG,
     CLERI_GID_K_UPTIME,
     CLERI_GID_K_USER,
     CLERI_GID_K_USERS,
@@ -252,6 +264,7 @@ enum cleri_grammar_ids {
     CLERI_GID_LIST_SERVERS,
     CLERI_GID_LIST_SHARDS,
     CLERI_GID_LIST_STMT,
+    CLERI_GID_LIST_TAGS,
     CLERI_GID_LIST_USERS,
     CLERI_GID_LOG_KEYWORDS,
     CLERI_GID_MERGE_AS,
@@ -302,8 +315,12 @@ enum cleri_grammar_ids {
     CLERI_GID_STRING,
     CLERI_GID_STR_OPERATOR,
     CLERI_GID_SUFFIX_EXPR,
+    CLERI_GID_TAG_COLUMNS,
+    CLERI_GID_TAG_NAME,
+    CLERI_GID_TAG_SERIES,
     CLERI_GID_TIMEIT_STMT,
     CLERI_GID_TIME_EXPR,
+    CLERI_GID_UNTAG_SERIES,
     CLERI_GID_USER_COLUMNS,
     CLERI_GID_UUID,
     CLERI_GID_WHERE_GROUP,
@@ -311,6 +328,7 @@ enum cleri_grammar_ids {
     CLERI_GID_WHERE_SERIES,
     CLERI_GID_WHERE_SERVER,
     CLERI_GID_WHERE_SHARD,
+    CLERI_GID_WHERE_TAG,
     CLERI_GID_WHERE_USER,
     CLERI_GID__BOOLEAN,
     CLERI_END // can be used to get the enum length
