@@ -210,13 +210,21 @@ siridb_t * siridb_new(const char * dbpath, int lock_flags)
     }
 
     /* load groups */
-    if ((siridb->groups = siridb_groups_new(siridb)) == NULL)
+    if (siridb_groups_init(siridb))
     {
         log_error("Cannot read groups for database '%s'", siridb->dbname);
         siridb_decref(siridb);
         return NULL;
     }
 
+    /* load tags */
+    if (siridb_tags_init(siridb))
+    {
+        log_error("Cannot read tags for database '%s'", siridb->dbname);
+        siridb_decref(siridb);
+        return NULL;
+    }
+
     /* update series props */
     log_info("Updating series properties");
 
@@ -676,6 +684,7 @@ int siridb_save(siridb_t * siridb)
             qp_close(fpacker));
 }
 
+
 /*
  * Destroy SiriDB object.
  *
@@ -686,7 +695,7 @@ void siridb__free(siridb_t * siridb)
     /* first we should close the buffer and all other open files */
     if (siridb->buffer != NULL)
     {
-        siridb_buffer_free(siridb->buffer);
+        siridb_buffer_close(siridb->buffer);
     }
 
     if (siridb->dropped_fp != NULL)
@@ -756,7 +765,7 @@ void siridb__free(siridb_t * siridb)
     /* free shards using imap walk an free the imap */
     if (siridb->shards != NULL)
     {
-        imap_free(siridb->shards, (imap_free_cb) &siridb__shard_decref);
+        imap_free(siridb->shards, (imap_free_cb) &siridb_shards_destroy_cb);
     }
 
     if (siridb->groups != NULL)
@@ -765,6 +774,16 @@ void siridb__free(siridb_t * siridb)
         siridb_groups_decref(siridb->groups);
     }
 
+    if (siridb->tags != NULL)
+    {
+         siridb_tags_decref(siridb->tags);
+    }
+
+    if (siridb->buffer != NULL)
+    {
+        siridb_buffer_free(siridb->buffer);
+    }
+
     if (siridb->tee != NULL)
     {
         siridb_tee_free(siridb->tee);
@@ -882,7 +901,8 @@ static siridb_t * siridb__new(void)
     siridb->replicate = NULL;
     siridb->reindex = NULL;
     siridb->groups = NULL;
-    siridb->dropped_fp = NULL;
+    siridb->groups = NULL;
+    siridb->tags = NULL;
     siridb->store = NULL;
     siridb->exp_at_log = 0;
     siridb->exp_at_num = 0;
