@@ -28,6 +28,30 @@ if (map)                                \
     qp_add_raw(packer, (const unsigned char *) "value", 5);     \
 }
 
+static siridb_props_cb SIRIDB_PROPS[KW_COUNT];
+
+siridb_props_cb props_get_cb(int i)
+{
+    return SIRIDB_PROPS[i];
+}
+
+static void props_set_cb(int i, siridb_props_cb cb)
+{
+    SIRIDB_PROPS[i] = cb;
+}
+
+static char * WHO_AM_I = NULL;
+
+void props_set_who_am_i(char * s)
+{
+    WHO_AM_I = s;
+}
+
+char * props_get_who_am_i(void)
+{
+    return WHO_AM_I;
+}
+
 static void prop_active_handles(
         siridb_t * siridb,
         qp_packer_t * packer,
@@ -177,91 +201,89 @@ static void prop_who_am_i(
         qp_packer_t * packer,
         int map);
 
-extern char * who_am_i;
-
 void siridb_init_props(void)
 {
     uint_fast16_t i;
 
     for (i = 0; i < KW_COUNT; i++)
     {
-        siridb_props[i] = NULL;
+        props_set_cb(i, NULL);
     }
 
-    siridb_props[CLERI_GID_K_ACTIVE_HANDLES - KW_OFFSET] =
-            prop_active_handles;
-    siridb_props[CLERI_GID_K_ACTIVE_TASKS - KW_OFFSET] =
-            prop_active_tasks;
-    siridb_props[CLERI_GID_K_BUFFER_PATH - KW_OFFSET] =
-            prop_buffer_path;
-    siridb_props[CLERI_GID_K_BUFFER_SIZE - KW_OFFSET] =
-            prop_buffer_size;
-    siridb_props[CLERI_GID_K_DBNAME - KW_OFFSET] =
-            prop_dbname;
-    siridb_props[CLERI_GID_K_DBPATH - KW_OFFSET] =
-            prop_dbpath;
-    siridb_props[CLERI_GID_K_DROP_THRESHOLD - KW_OFFSET] =
-            prop_drop_threshold;
-    siridb_props[CLERI_GID_K_DURATION_LOG - KW_OFFSET] =
-            prop_duration_log;
-    siridb_props[CLERI_GID_K_DURATION_NUM - KW_OFFSET] =
-            prop_duration_num;
-    siridb_props[CLERI_GID_K_FIFO_FILES - KW_OFFSET] =
-            prop_fifo_files;
-    siridb_props[CLERI_GID_K_EXPIRATION_LOG - KW_OFFSET] =
-            prop_expiration_log;
-    siridb_props[CLERI_GID_K_EXPIRATION_NUM - KW_OFFSET] =
-            prop_expiration_num;
-    siridb_props[CLERI_GID_K_IDLE_PERCENTAGE - KW_OFFSET] =
-            prop_idle_percentage;
-    siridb_props[CLERI_GID_K_IDLE_TIME - KW_OFFSET] =
-            prop_idle_time;
-    siridb_props[CLERI_GID_K_IP_SUPPORT - KW_OFFSET] =
-            prop_ip_support;
-    siridb_props[CLERI_GID_K_LIBUV - KW_OFFSET] =
-            prop_libuv;
-    siridb_props[CLERI_GID_K_LIST_LIMIT - KW_OFFSET] =
-            prop_list_limit;
-    siridb_props[CLERI_GID_K_MAX_OPEN_FILES - KW_OFFSET] =
-            prop_max_open_files;
-    siridb_props[CLERI_GID_K_MEM_USAGE - KW_OFFSET] =
-            prop_mem_usage;
-    siridb_props[CLERI_GID_K_LOG_LEVEL - KW_OFFSET] =
-            prop_log_level;
-    siridb_props[CLERI_GID_K_OPEN_FILES - KW_OFFSET] =
-            prop_open_files;
-    siridb_props[CLERI_GID_K_POOL - KW_OFFSET] =
-            prop_pool;
-    siridb_props[CLERI_GID_K_RECEIVED_POINTS - KW_OFFSET] =
-            prop_received_points;
-    siridb_props[CLERI_GID_K_REINDEX_PROGRESS - KW_OFFSET] =
-            prop_reindex_progress;
-    siridb_props[CLERI_GID_K_SELECTED_POINTS - KW_OFFSET] =
-            prop_selected_points;
-    siridb_props[CLERI_GID_K_SELECT_POINTS_LIMIT - KW_OFFSET] =
-            prop_select_points_limit;
-    siridb_props[CLERI_GID_K_SERVER - KW_OFFSET] =
-            prop_server;
-    siridb_props[CLERI_GID_K_STARTUP_TIME - KW_OFFSET] =
-            prop_startup_time;
-    siridb_props[CLERI_GID_K_STATUS - KW_OFFSET] =
-            prop_status;
-    siridb_props[CLERI_GID_K_SYNC_PROGRESS - KW_OFFSET] =
-            prop_sync_progress;
-    siridb_props[CLERI_GID_K_TEE_PIPE_NAME - KW_OFFSET] =
-            prop_tee_pipe_name;
-    siridb_props[CLERI_GID_K_TIMEZONE - KW_OFFSET] =
-            prop_timezone;
-    siridb_props[CLERI_GID_K_TIME_PRECISION - KW_OFFSET] =
-            prop_time_precision;
-    siridb_props[CLERI_GID_K_UPTIME - KW_OFFSET] =
-            prop_uptime;
-    siridb_props[CLERI_GID_K_UUID - KW_OFFSET] =
-            prop_uuid;
-    siridb_props[CLERI_GID_K_VERSION - KW_OFFSET] =
-            prop_version;
-    siridb_props[CLERI_GID_K_WHO_AM_I - KW_OFFSET] =
-            prop_who_am_i;
+    props_set_cb(CLERI_GID_K_ACTIVE_HANDLES - KW_OFFSET,
+            prop_active_handles);
+    props_set_cb(CLERI_GID_K_ACTIVE_TASKS - KW_OFFSET,
+            prop_active_tasks);
+    props_set_cb(CLERI_GID_K_BUFFER_PATH - KW_OFFSET,
+            prop_buffer_path);
+    props_set_cb(CLERI_GID_K_BUFFER_SIZE - KW_OFFSET,
+            prop_buffer_size);
+    props_set_cb(CLERI_GID_K_DBNAME - KW_OFFSET,
+            prop_dbname);
+    props_set_cb(CLERI_GID_K_DBPATH - KW_OFFSET,
+            prop_dbpath);
+    props_set_cb(CLERI_GID_K_DROP_THRESHOLD - KW_OFFSET,
+            prop_drop_threshold);
+    props_set_cb(CLERI_GID_K_DURATION_LOG - KW_OFFSET,
+            prop_duration_log);
+    props_set_cb(CLERI_GID_K_DURATION_NUM - KW_OFFSET,
+            prop_duration_num);
+    props_set_cb(CLERI_GID_K_FIFO_FILES - KW_OFFSET,
+            prop_fifo_files);
+    props_set_cb(CLERI_GID_K_EXPIRATION_LOG - KW_OFFSET,
+            prop_expiration_log);
+    props_set_cb(CLERI_GID_K_EXPIRATION_NUM - KW_OFFSET,
+            prop_expiration_num);
+    props_set_cb(CLERI_GID_K_IDLE_PERCENTAGE - KW_OFFSET,
+            prop_idle_percentage);
+    props_set_cb(CLERI_GID_K_IDLE_TIME - KW_OFFSET,
+            prop_idle_time);
+    props_set_cb(CLERI_GID_K_IP_SUPPORT - KW_OFFSET,
+            prop_ip_support);
+    props_set_cb(CLERI_GID_K_LIBUV - KW_OFFSET,
+            prop_libuv);
+    props_set_cb(CLERI_GID_K_LIST_LIMIT - KW_OFFSET,
+            prop_list_limit);
+    props_set_cb(CLERI_GID_K_MAX_OPEN_FILES - KW_OFFSET,
+            prop_max_open_files);
+    props_set_cb(CLERI_GID_K_MEM_USAGE - KW_OFFSET,
+            prop_mem_usage);
+    props_set_cb(CLERI_GID_K_LOG_LEVEL - KW_OFFSET,
+            prop_log_level);
+    props_set_cb(CLERI_GID_K_OPEN_FILES - KW_OFFSET,
+            prop_open_files);
+    props_set_cb(CLERI_GID_K_POOL - KW_OFFSET,
+            prop_pool);
+    props_set_cb(CLERI_GID_K_RECEIVED_POINTS - KW_OFFSET,
+            prop_received_points);
+    props_set_cb(CLERI_GID_K_REINDEX_PROGRESS - KW_OFFSET,
+            prop_reindex_progress);
+    props_set_cb(CLERI_GID_K_SELECTED_POINTS - KW_OFFSET,
+            prop_selected_points);
+    props_set_cb(CLERI_GID_K_SELECT_POINTS_LIMIT - KW_OFFSET,
+            prop_select_points_limit);
+    props_set_cb(CLERI_GID_K_SERVER - KW_OFFSET,
+            prop_server);
+    props_set_cb(CLERI_GID_K_STARTUP_TIME - KW_OFFSET,
+            prop_startup_time);
+    props_set_cb(CLERI_GID_K_STATUS - KW_OFFSET,
+            prop_status);
+    props_set_cb(CLERI_GID_K_SYNC_PROGRESS - KW_OFFSET,
+            prop_sync_progress);
+    props_set_cb(CLERI_GID_K_TEE_PIPE_NAME - KW_OFFSET,
+            prop_tee_pipe_name);
+    props_set_cb(CLERI_GID_K_TIMEZONE - KW_OFFSET,
+            prop_timezone);
+    props_set_cb(CLERI_GID_K_TIME_PRECISION - KW_OFFSET,
+            prop_time_precision);
+    props_set_cb(CLERI_GID_K_UPTIME - KW_OFFSET,
+            prop_uptime);
+    props_set_cb(CLERI_GID_K_UUID - KW_OFFSET,
+            prop_uuid);
+    props_set_cb(CLERI_GID_K_VERSION - KW_OFFSET,
+            prop_version);
+    props_set_cb(CLERI_GID_K_WHO_AM_I - KW_OFFSET,
+            prop_who_am_i);
 }
 
 static void prop_active_handles(
@@ -578,7 +600,7 @@ static void prop_time_precision(
     assert (siridb->time->precision >= SIRIDB_TIME_SECONDS &&
             siridb->time->precision <= SIRIDB_TIME_NANOSECONDS);
 
-    qp_add_string(packer, siridb_time_short_map[siridb->time->precision]);
+    qp_add_string(packer, siridb_time_short_map(siridb->time->precision));
 }
 
 static void prop_uptime(
@@ -616,5 +638,5 @@ static void prop_who_am_i(
         int map)
 {
     SIRIDB_PROP_MAP("who_am_i", 8)
-    qp_add_string(packer, who_am_i);
+    qp_add_string(packer, props_get_who_am_i());
 }
