@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2020-01-23 14:08:47
+ * Created at: 2020-09-25 10:57:26
  */
 
 #include "siri/grammar/grammar.h"
@@ -58,6 +58,8 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * k_duration_num = cleri_keyword(CLERI_GID_K_DURATION_NUM, "duration_num", CLERI_CASE_SENSITIVE);
     cleri_t * k_end = cleri_keyword(CLERI_GID_K_END, "end", CLERI_CASE_SENSITIVE);
     cleri_t * k_error = cleri_keyword(CLERI_GID_K_ERROR, "error", CLERI_CASE_SENSITIVE);
+    cleri_t * k_expiration_log = cleri_keyword(CLERI_GID_K_EXPIRATION_LOG, "expiration_log", CLERI_CASE_SENSITIVE);
+    cleri_t * k_expiration_num = cleri_keyword(CLERI_GID_K_EXPIRATION_NUM, "expiration_num", CLERI_CASE_SENSITIVE);
     cleri_t * k_expression = cleri_keyword(CLERI_GID_K_EXPRESSION, "expression", CLERI_CASE_SENSITIVE);
     cleri_t * k_false = cleri_keyword(CLERI_GID_K_FALSE, "false", CLERI_CASE_SENSITIVE);
     cleri_t * k_fifo_files = cleri_keyword(CLERI_GID_K_FIFO_FILES, "fifo_files", CLERI_CASE_SENSITIVE);
@@ -91,6 +93,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_token(CLERI_NONE, "&"),
         cleri_keyword(CLERI_NONE, "intersection", CLERI_CASE_SENSITIVE)
     );
+    cleri_t * k_interval = cleri_keyword(CLERI_GID_K_INTERVAL, "interval", CLERI_CASE_SENSITIVE);
     cleri_t * k_ip_support = cleri_keyword(CLERI_GID_K_IP_SUPPORT, "ip_support", CLERI_CASE_SENSITIVE);
     cleri_t * k_last = cleri_keyword(CLERI_GID_K_LAST, "last", CLERI_CASE_SENSITIVE);
     cleri_t * k_length = cleri_keyword(CLERI_GID_K_LENGTH, "length", CLERI_CASE_SENSITIVE);
@@ -141,8 +144,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * k_server = cleri_keyword(CLERI_GID_K_SERVER, "server", CLERI_CASE_SENSITIVE);
     cleri_t * k_servers = cleri_keyword(CLERI_GID_K_SERVERS, "servers", CLERI_CASE_SENSITIVE);
     cleri_t * k_set = cleri_keyword(CLERI_GID_K_SET, "set", CLERI_CASE_SENSITIVE);
-    cleri_t * k_expiration_log = cleri_keyword(CLERI_GID_K_EXPIRATION_LOG, "expiration_log", CLERI_CASE_SENSITIVE);
-    cleri_t * k_expiration_num = cleri_keyword(CLERI_GID_K_EXPIRATION_NUM, "expiration_num", CLERI_CASE_SENSITIVE);
+    cleri_t * k_shard_duration = cleri_keyword(CLERI_GID_K_SHARD_DURATION, "shard_duration", CLERI_CASE_SENSITIVE);
     cleri_t * k_shards = cleri_keyword(CLERI_GID_K_SHARDS, "shards", CLERI_CASE_SENSITIVE);
     cleri_t * k_show = cleri_keyword(CLERI_GID_K_SHOW, "show", CLERI_CASE_SENSITIVE);
     cleri_t * k_sid = cleri_keyword(CLERI_GID_K_SID, "sid", CLERI_CASE_SENSITIVE);
@@ -162,10 +164,13 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_keyword(CLERI_NONE, "symmetric_difference", CLERI_CASE_SENSITIVE)
     );
     cleri_t * k_sync_progress = cleri_keyword(CLERI_GID_K_SYNC_PROGRESS, "sync_progress", CLERI_CASE_SENSITIVE);
+    cleri_t * k_tag = cleri_keyword(CLERI_GID_K_TAG, "tag", CLERI_CASE_SENSITIVE);
+    cleri_t * k_tags = cleri_keyword(CLERI_GID_K_TAGS, "tags", CLERI_CASE_SENSITIVE);
     cleri_t * k_tee_pipe_name = cleri_keyword(CLERI_GID_K_TEE_PIPE_NAME, "tee_pipe_name", CLERI_CASE_SENSITIVE);
-    cleri_t * k_timeit = cleri_keyword(CLERI_GID_K_TIMEIT, "timeit", CLERI_CASE_SENSITIVE);
-    cleri_t * k_timezone = cleri_keyword(CLERI_GID_K_TIMEZONE, "timezone", CLERI_CASE_SENSITIVE);
     cleri_t * k_time_precision = cleri_keyword(CLERI_GID_K_TIME_PRECISION, "time_precision", CLERI_CASE_SENSITIVE);
+    cleri_t * k_timeit = cleri_keyword(CLERI_GID_K_TIMEIT, "timeit", CLERI_CASE_SENSITIVE);
+    cleri_t * k_timeval = cleri_keyword(CLERI_GID_K_TIMEVAL, "timeval", CLERI_CASE_SENSITIVE);
+    cleri_t * k_timezone = cleri_keyword(CLERI_GID_K_TIMEZONE, "timezone", CLERI_CASE_SENSITIVE);
     cleri_t * k_to = cleri_keyword(CLERI_GID_K_TO, "to", CLERI_CASE_SENSITIVE);
     cleri_t * k_true = cleri_keyword(CLERI_GID_K_TRUE, "true", CLERI_CASE_SENSITIVE);
     cleri_t * k_type = cleri_keyword(CLERI_GID_K_TYPE, "type", CLERI_CASE_SENSITIVE);
@@ -176,6 +181,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_tokens(CLERI_NONE, ", |"),
         cleri_keyword(CLERI_NONE, "union", CLERI_CASE_SENSITIVE)
     );
+    cleri_t * k_untag = cleri_keyword(CLERI_GID_K_UNTAG, "untag", CLERI_CASE_SENSITIVE);
     cleri_t * k_uptime = cleri_keyword(CLERI_GID_K_UPTIME, "uptime", CLERI_CASE_SENSITIVE);
     cleri_t * k_user = cleri_keyword(CLERI_GID_K_USER, "user", CLERI_CASE_SENSITIVE);
     cleri_t * k_users = cleri_keyword(CLERI_GID_K_USERS, "users", CLERI_CASE_SENSITIVE);
@@ -281,12 +287,13 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * series_columns = cleri_list(CLERI_GID_SERIES_COLUMNS, cleri_choice(
         CLERI_NONE,
         CLERI_FIRST_MATCH,
-        6,
+        7,
         k_name,
         k_type,
         k_length,
         k_start,
         k_end,
+        k_shard_duration,
         k_pool
     ), cleri_token(CLERI_NONE, ","), 1, 0, 0);
     cleri_t * shard_columns = cleri_list(CLERI_GID_SHARD_COLUMNS, cleri_choice(
@@ -351,6 +358,13 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_name,
         k_access
     ), cleri_token(CLERI_NONE, ","), 1, 0, 0);
+    cleri_t * tag_columns = cleri_list(CLERI_GID_TAG_COLUMNS, cleri_choice(
+        CLERI_NONE,
+        CLERI_FIRST_MATCH,
+        2,
+        k_name,
+        k_series
+    ), cleri_token(CLERI_NONE, ","), 1, 0, 0);
     cleri_t * pool_props = cleri_choice(
         CLERI_GID_POOL_PROPS,
         CLERI_FIRST_MATCH,
@@ -413,6 +427,50 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             )
         )
     );
+    cleri_t * where_tag = cleri_sequence(
+        CLERI_GID_WHERE_TAG,
+        2,
+        k_where,
+        cleri_prio(
+            CLERI_NONE,
+            5,
+            cleri_sequence(
+                CLERI_NONE,
+                3,
+                k_name,
+                str_operator,
+                string
+            ),
+            cleri_sequence(
+                CLERI_NONE,
+                3,
+                k_series,
+                int_operator,
+                int_expr
+            ),
+            cleri_sequence(
+                CLERI_NONE,
+                3,
+                cleri_token(CLERI_NONE, "("),
+                CLERI_THIS,
+                cleri_token(CLERI_NONE, ")")
+            ),
+            cleri_sequence(
+                CLERI_NONE,
+                3,
+                CLERI_THIS,
+                k_and,
+                CLERI_THIS
+            ),
+            cleri_sequence(
+                CLERI_NONE,
+                3,
+                CLERI_THIS,
+                k_or,
+                CLERI_THIS
+            )
+        )
+    );
     cleri_t * where_pool = cleri_sequence(
         CLERI_GID_WHERE_POOL,
         2,
@@ -483,9 +541,10 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
                 cleri_choice(
                     CLERI_NONE,
                     CLERI_FIRST_MATCH,
-                    2,
+                    3,
                     k_start,
-                    k_end
+                    k_end,
+                    k_shard_duration
                 ),
                 int_operator,
                 time_expr
@@ -772,6 +831,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     );
     cleri_t * series_name = cleri_dup(CLERI_GID_SERIES_NAME, string);
     cleri_t * group_name = cleri_dup(CLERI_GID_GROUP_NAME, r_grave_str);
+    cleri_t * tag_name = cleri_dup(CLERI_GID_TAG_NAME, r_grave_str);
     cleri_t * series_re = cleri_dup(CLERI_GID_SERIES_RE, r_regex);
     cleri_t * uuid = cleri_choice(
         CLERI_GID_UUID,
@@ -780,7 +840,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         r_uuid_str,
         string
     );
-    cleri_t * group_match = cleri_dup(CLERI_GID_GROUP_MATCH, r_grave_str);
+    cleri_t * group_tag_match = cleri_dup(CLERI_GID_GROUP_TAG_MATCH, r_grave_str);
     cleri_t * series_match = cleri_prio(
         CLERI_GID_SERIES_MATCH,
         4,
@@ -790,7 +850,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             4,
             series_all,
             series_name,
-            group_match,
+            group_tag_match,
             series_re
         ), series_setopr, 1, 0, 0),
         cleri_choice(
@@ -799,7 +859,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             4,
             series_all,
             series_name,
-            group_match,
+            group_tag_match,
             series_re
         ),
         series_parentheses,
@@ -978,6 +1038,20 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_optional(CLERI_NONE, time_expr),
         cleri_token(CLERI_NONE, ")")
     );
+    cleri_t * f_timeval = cleri_sequence(
+        CLERI_GID_F_TIMEVAL,
+        3,
+        k_timeval,
+        cleri_token(CLERI_NONE, "("),
+        cleri_token(CLERI_NONE, ")")
+    );
+    cleri_t * f_interval = cleri_sequence(
+        CLERI_GID_F_INTERVAL,
+        3,
+        k_interval,
+        cleri_token(CLERI_NONE, "("),
+        cleri_token(CLERI_NONE, ")")
+    );
     cleri_t * f_filter = cleri_sequence(
         CLERI_GID_F_FILTER,
         5,
@@ -1028,7 +1102,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
     cleri_t * aggregate_functions = cleri_list(CLERI_GID_AGGREGATE_FUNCTIONS, cleri_choice(
         CLERI_NONE,
         CLERI_FIRST_MATCH,
-        19,
+        21,
         f_all,
         f_limit,
         f_mean,
@@ -1044,6 +1118,8 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         f_stddev,
         f_first,
         f_last,
+        f_timeval,
+        f_interval,
         f_difference,
         f_derivative,
         f_filter,
@@ -1167,6 +1243,18 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_timezone,
         string
     );
+    cleri_t * tag_series = cleri_sequence(
+        CLERI_GID_TAG_SERIES,
+        2,
+        k_tag,
+        tag_name
+    );
+    cleri_t * untag_series = cleri_sequence(
+        CLERI_GID_UNTAG_SERIES,
+        2,
+        k_untag,
+        tag_name
+    );
     cleri_t * set_expiration_num = cleri_sequence(
         CLERI_GID_SET_EXPIRATION_NUM,
         4,
@@ -1212,6 +1300,18 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             set_name
         )
     );
+    cleri_t * alter_tag = cleri_sequence(
+        CLERI_GID_ALTER_TAG,
+        3,
+        k_tag,
+        tag_name,
+        cleri_choice(
+            CLERI_NONE,
+            CLERI_FIRST_MATCH,
+            1,
+            set_name
+        )
+    );
     cleri_t * alter_server = cleri_sequence(
         CLERI_GID_ALTER_SERVER,
         3,
@@ -1254,12 +1354,32 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             set_name
         )
     );
+    cleri_t * alter_series = cleri_sequence(
+        CLERI_GID_ALTER_SERIES,
+        4,
+        k_series,
+        series_match,
+        cleri_optional(CLERI_NONE, where_series),
+        cleri_choice(
+            CLERI_NONE,
+            CLERI_FIRST_MATCH,
+            2,
+            tag_series,
+            untag_series
+        )
+    );
     cleri_t * count_groups = cleri_sequence(
         CLERI_GID_COUNT_GROUPS,
         2,
         k_groups,
         cleri_optional(CLERI_NONE, where_group)
     );
+    cleri_t * count_tags = cleri_sequence(
+        CLERI_GID_COUNT_TAGS,
+        2,
+        k_tags,
+        cleri_optional(CLERI_NONE, where_tag)
+    );
     cleri_t * count_pools = cleri_sequence(
         CLERI_GID_COUNT_POOLS,
         2,
@@ -1341,6 +1461,12 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         k_group,
         group_name
     );
+    cleri_t * drop_tag = cleri_sequence(
+        CLERI_GID_DROP_TAG,
+        2,
+        k_tag,
+        tag_name
+    );
     cleri_t * drop_series = cleri_sequence(
         CLERI_GID_DROP_SERIES,
         4,
@@ -1382,6 +1508,13 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_optional(CLERI_NONE, group_columns),
         cleri_optional(CLERI_NONE, where_group)
     );
+    cleri_t * list_tags = cleri_sequence(
+        CLERI_GID_LIST_TAGS,
+        3,
+        k_tags,
+        cleri_optional(CLERI_NONE, tag_columns),
+        cleri_optional(CLERI_NONE, where_tag)
+    );
     cleri_t * list_pools = cleri_sequence(
         CLERI_GID_LIST_POOLS,
         3,
@@ -1431,9 +1564,11 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            5,
+            7,
+            alter_series,
             alter_user,
             alter_group,
+            alter_tag,
             alter_server,
             alter_servers,
             alter_database
@@ -1447,7 +1582,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_MOST_GREEDY,
-            10,
+            11,
             count_groups,
             count_pools,
             count_series,
@@ -1457,6 +1592,7 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
             count_shards,
             count_shards_size,
             count_users,
+            count_tags,
             count_series_length
         )
     );
@@ -1479,8 +1615,9 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            5,
+            6,
             drop_group,
+            drop_tag,
             drop_series,
             drop_shards,
             drop_server,
@@ -1507,8 +1644,9 @@ cleri_grammar_t * compile_siri_grammar_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_FIRST_MATCH,
-            6,
+            7,
             list_series,
+            list_tags,
             list_users,
             list_shards,
             list_groups,
